@@ -67,6 +67,8 @@ def merge_players(results, players):
     """Merge player data."""
     for player in players:
         name = player.get('liquipedia', player['name']).lower()
+        if 'notability' in player:
+            del player['notability']
         if name not in results:
             continue
         for field, overwrite, is_list in [('twitter', False, True), ('liquipedia', False, False), ('twitch', False, True), ('youtube', False, True)]: #, ('team', True)]:
