@@ -9,13 +9,14 @@ import requests
 from ruamel.yaml import YAML
 import wikitextparser as wtp
 
-BLACKLIST = ['simtom', 'Ardeshir']
+BLACKLIST = ['simtom', 'Ardeshir', 'Adam', 'Maxxtro', 'Xerxes', 'GyoreE', 'trombone', 'Rideg', 'Kiwi', '']
 LOGGER = logging.getLogger(__name__)
 WAIT_SECS = 30
 PAGE_SIZE = 500
 CONDITIONS = [
     'Category:Age of Empires II Players',
-    'Is player::true'
+    'Is player::true',
+    'Has aoe2net id::+'
 ]
 PROPS = [
     'Has pagename',
@@ -82,14 +83,17 @@ def get_props(page, props):
                 out[a.name.strip()] = a.value.strip()
     return out
 
+def clean(name):
+    return name.lower().replace("_", " ").strip()
 
 def find_new(result_data, player_data, last_id):
-    seen = set([p['liquipedia'].lower().replace("_", " ").strip() for p in player_data if 'liquipedia' in p])
-    seen |= set([p['name'].lower().replace("_", " ").strip() for p in player_data])
+    seen = set([clean(p['liquipedia']) for p in player_data if 'liquipedia' in p])
+    seen |= set([clean(p['name']) for p in player_data])
     for n in result_data:
-        if n['name'].lower().replace("_", " ").strip() not in seen:
-            props = get_props(n['page'], ['country', 'aoe2net_id'])
+        if clean(n['name']) not in seen:
+            props = get_props(n['page'], ['country', 'aoe2net_id', 'aoe-elo.com_id'])
             if 'aoe2net_id' not in props or not props['aoe2net_id']:
+                print(f"error: no aoe2net id for {n['name']}")
                 continue
             country_code = pycountry.countries.search_fuzzy(props['country'])[0].alpha_2.lower()
             last_id += 1
@@ -104,6 +108,7 @@ def find_new(result_data, player_data, last_id):
                 ),
                 liquipedia=n['name'],
                 id=last_id,
+                aoeelo=int(props['aoe-elo.com_id']) if 'aoe-elo.com_id' in props and props['aoe-elo.com_id'] else None,
                 notability=dict(aoe2=True)
             ))
 
