@@ -61,7 +61,7 @@ def fetch(conditions, props):
             # {'Has id': ['Ace'], 'Has team': [{'fulltext': 'InDuS', 'fullurl': 'https://liquipedia.net/ageofempires/InDuS', 'namespace': 0, 'exists': '1', 'displaytitle': ''}]}
             #name = record['Has id'][0]
             name = None
-            if 'Has pagename' in record:
+            if 'Has pagename' in record and record['Has pagename']:
                 name = record['Has pagename'][0]['displaytitle']
             elif 'Has id' in record and record['Has id']:
                 name = record['Has id'][0]
@@ -89,7 +89,10 @@ def strip_leading_double_space(stream):
 
 MANUAL = {
     'CZ': {'Skull'},
-    'Hot Young Masters': {'Dr.Kozmonot', 'Ubetnir'}
+    'Hot Young Masters': {'Dr.Kozmonot', 'Ubetnir'},
+    'One Punch': {'fatman'},
+    'Dark Empire': {'Xhing'},
+    'İstanbul Wildcats': {'Kasva'}
 }
 
 def main():
@@ -109,9 +112,9 @@ def main():
     names = set()
     result_data = defaultdict(set)
     for p in player_data:
-        names.add(p['name'].lower().replace('_', ''))
+        names.add(p['name'].lower().replace('_', '').replace(' ', ''))
         if 'liquipedia' in p:
-            names.add(p['liquipedia'].lower().replace('_', ''))
+            names.add(p['liquipedia'].lower().replace('_', '').replace(' ', ''))
     LOGGER.info("starting data update")
     for x, y in MANUAL.items():
         result_data[x] |= y
@@ -128,17 +131,20 @@ def main():
     p2t = {}
     BLACKLIST = ['MMC eSports', 'The Jedi Masters']
     PLAYER_BLACKLIST = ['DaRk_']
+    for pp in player_data:
+        if 'team' in pp:
+            del pp['team']
     for x, y in result_data.items():
         if x in BLACKLIST:
             continue
-        tm = {f for f in y if f.lower().replace('_', '') in names and f not in PLAYER_BLACKLIST}
+        tm = {f for f in y if f.lower().replace('_', '').replace(' ', '') in names and f not in PLAYER_BLACKLIST}
         if tm:
             players = set()
             pns = set()
             for p in tm:
-                ptrans = p.lower().replace('_', '')
+                ptrans = p.lower().replace('_', '').replace(' ', '')
                 for pp in player_data:
-                    if ptrans == pp['name'].lower().replace('_', '') or 'liquipedia' in pp and ptrans == pp['liquipedia'].lower().replace('_', ''):
+                    if ptrans == pp['name'].lower().replace('_', '').replace(' ', '') or 'liquipedia' in pp and ptrans == pp['liquipedia'].lower().replace('_', '').replace(' ', ''):
                         pp['team'] = id
                         players.add(pp['id'])
                         pns.add(p)
